@@ -52,7 +52,7 @@ try:
 except ImportError:
     pass
 
-__version__ = "3.3.14"
+__version__ = "3.3.15"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_SD.git"
 
 _CMD_TIMEOUT = const(200)
@@ -202,6 +202,7 @@ class SDCard:
 
     # pylint: disable-msg=too-many-arguments
     # pylint: disable=no-member
+    # pylint: disable-msg=too-many-branches
     # no-member disable should be reconsidered when it can be tested
     def _cmd(
         self,
@@ -248,6 +249,7 @@ class SDCard:
 
         card.write(buf)
 
+        # pylint: disable-msg=too-many-nested-blocks
         # wait for the response (response[7] == 0)
         for _ in range(_CMD_TIMEOUT):
             card.readinto(buf, end=1, write_value=0xFF)
@@ -256,8 +258,12 @@ class SDCard:
                     if data_block:
                         # Wait for the start block byte
                         buf[1] = 0xFF
-                        while buf[1] != 0xFE:
+                        for _ in range(_CMD_TIMEOUT):
                             card.readinto(buf, start=1, end=2, write_value=0xFF)
+                            if buf[1] == 0xFE:
+                                break
+                        if buf[1] != 0xFE:
+                            return -1
                     card.readinto(response_buf, write_value=0xFF)
                     if data_block:
                         # Read the checksum
@@ -265,6 +271,7 @@ class SDCard:
                 return buf[0]
         return -1
 
+    # pylint: enable-msg=too-many-branches
     # pylint: enable-msg=too-many-arguments
 
     # pylint: disable-msg=too-many-arguments
